@@ -31,16 +31,20 @@ class AddDeviceRequest(AbstractModel):
         :type Remark: str
         :param DataKey: 新建设备的base64密钥字符串，非必选，如果不填写则由系统自动生成
         :type DataKey: str
+        :param Encrypted: 是否设置预置密钥
+        :type Encrypted: bool
         """
         self.DeviceName = None
         self.Remark = None
         self.DataKey = None
+        self.Encrypted = None
 
 
     def _deserialize(self, params):
         self.DeviceName = params.get("DeviceName")
         self.Remark = params.get("Remark")
         self.DataKey = params.get("DataKey")
+        self.Encrypted = params.get("Encrypted")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -57,21 +61,26 @@ class AddDeviceResponse(AbstractModel):
 
     def __init__(self):
         r"""
-        :param DataKey: 后台生成的base64字符串密钥
+        :param DataKey: 经过加密算法加密后的base64格式密钥
         :type DataKey: str
         :param DeviceId: 设备ID
         :type DeviceId: str
+        :param Signature: 签名字符串
+注意：此字段可能返回 null，表示取不到有效值。
+        :type Signature: str
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
         self.DataKey = None
         self.DeviceId = None
+        self.Signature = None
         self.RequestId = None
 
 
     def _deserialize(self, params):
         self.DataKey = params.get("DataKey")
         self.DeviceId = params.get("DeviceId")
+        self.Signature = params.get("Signature")
         self.RequestId = params.get("RequestId")
 
 
@@ -141,6 +150,33 @@ class Context(AbstractModel):
         
 
 
+class CreateEncryptedKeyRequest(AbstractModel):
+    """CreateEncryptedKey请求参数结构体
+
+    """
+
+
+class CreateEncryptedKeyResponse(AbstractModel):
+    """CreateEncryptedKey返回参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param EncryptedKey: 预置密钥
+        :type EncryptedKey: str
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.EncryptedKey = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.EncryptedKey = params.get("EncryptedKey")
+        self.RequestId = params.get("RequestId")
+
+
 class CreateQosRequest(AbstractModel):
     """CreateQos请求参数结构体
 
@@ -797,6 +833,111 @@ class GetDevicesResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
+class GetFlowStatisticRequest(AbstractModel):
+    """GetFlowStatistic请求参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param DeviceId: 设备ID，ID="-1"时默认查找所有设备
+        :type DeviceId: str
+        :param BeginTime: 开始查找时间
+        :type BeginTime: int
+        :param EndTime: 截止时间
+        :type EndTime: int
+        :param Type: 流量种类（1：上行流量，2：下行流量）
+        :type Type: int
+        :param TimeGranularity: 时间粒度（1：按小时统计，2：按天统计）
+        :type TimeGranularity: int
+        """
+        self.DeviceId = None
+        self.BeginTime = None
+        self.EndTime = None
+        self.Type = None
+        self.TimeGranularity = None
+
+
+    def _deserialize(self, params):
+        self.DeviceId = params.get("DeviceId")
+        self.BeginTime = params.get("BeginTime")
+        self.EndTime = params.get("EndTime")
+        self.Type = params.get("Type")
+        self.TimeGranularity = params.get("TimeGranularity")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class GetFlowStatisticResponse(AbstractModel):
+    """GetFlowStatistic返回参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param NetDetails: 流量详细信息
+        :type NetDetails: list of NetDetails
+        :param MaxValue: 查找时间段流量使用最大值（单位：bit）
+        :type MaxValue: float
+        :param AvgValue: 查找时间段流量使用平均值（单位：bit）
+        :type AvgValue: float
+        :param TotalValue: 查找时间段流量使用总量（单位：bit）
+        :type TotalValue: float
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.NetDetails = None
+        self.MaxValue = None
+        self.AvgValue = None
+        self.TotalValue = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        if params.get("NetDetails") is not None:
+            self.NetDetails = []
+            for item in params.get("NetDetails"):
+                obj = NetDetails()
+                obj._deserialize(item)
+                self.NetDetails.append(obj)
+        self.MaxValue = params.get("MaxValue")
+        self.AvgValue = params.get("AvgValue")
+        self.TotalValue = params.get("TotalValue")
+        self.RequestId = params.get("RequestId")
+
+
+class GetPublicKeyRequest(AbstractModel):
+    """GetPublicKey请求参数结构体
+
+    """
+
+
+class GetPublicKeyResponse(AbstractModel):
+    """GetPublicKey返回参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param PublicKey: 非对称公钥
+        :type PublicKey: str
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.PublicKey = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.PublicKey = params.get("PublicKey")
+        self.RequestId = params.get("RequestId")
+
+
 class GetStatisticDataRequest(AbstractModel):
     """GetStatisticData请求参数结构体
 
@@ -856,6 +997,34 @@ class GetStatisticDataResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
+class NetDetails(AbstractModel):
+    """网络详细信息
+
+    """
+
+    def __init__(self):
+        r"""
+        :param Time: 时间点，单位：s
+        :type Time: str
+        :param Current: 流量值（bit）
+        :type Current: float
+        """
+        self.Time = None
+        self.Current = None
+
+
+    def _deserialize(self, params):
+        self.Time = params.get("Time")
+        self.Current = params.get("Current")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
 class NetworkData(AbstractModel):
     """测速数据
 
